@@ -50,15 +50,15 @@ namespace Oxygen
         public Q_SLOTS:
 
         //! read current configuration
-        virtual void load( void );
+        void load( void ) ;
 
         //! save current configuration
-        virtual void save( void );
+        void save( void ) ;
 
         protected Q_SLOTS:
 
         //! check whether configuration is changed and emit appropriate signal if yes
-        virtual void updateChanged();
+        void updateChanged() ;
 
         private:
 
